module.exports = defineTest({
	description: 'tracks mutations of array elements'
});
